@@ -131,7 +131,10 @@ def time_till_metrics(vals, truth_val, expected_dt):
 def validity_nondecreasing_step(series, truth_df, expected_df, *args, **kwargs):
     truth_max = truth_df[expected_df.index < series.name].iloc[:, 0].max()
     num_expected_updates = len(expected_df[expected_df.index < series.name].iloc[:, 0].unique())
-    coef = -1 / (min(num_expected_updates, truth_max) / 5)
+    denom =  (min(num_expected_updates, truth_max) / 5)
+    if denom == 0:
+        return None
+    coef = -1 / denom
     num_increasing_updates = len(series[series.diff() > 0])
 
     return -1 + 2 / (1 + math.exp(coef * num_increasing_updates))
@@ -658,7 +661,11 @@ def plot_node(
 
     completed_stations = [each for each in body['completed_stations']]
 
+    print('Clearing Image')
+    plt.close()
+    print('Cleared Image')
     # plot truth data
+
     print("Creating Line Plot of Truth Values")
     truth_df = df_from_s3_csv(prepared_bucket, make_key(truth_file, path))
     image_name = 'truth_plot.png'
@@ -666,13 +673,16 @@ def plot_node(
     truth_df.iloc[:, -1].plot(kind="line")
     plt.title(fancy_path, fontsize=15)
     save_plt_to_s3(plt, to_bucket, make_key(image_name, path), format='png')
-    plt.clf()
+
+    print('Clearing Image')
+    plt.close()
     print('Cleared Image')
 
     # plot heatmap
     print("Creating Heatmap of Data")
     image_name = 'data_heatmap.png'
-    data_df = df_from_s3_csv(from_bucket, make_key(data_file, path))
+    data_df = df_from_s3_csv(prepared_bucket, make_key(data_file, path))
+    plt.figure(figsize=(12, 12))
     plt.pcolormesh(data_df, norm=LogNorm())
     len_ind = len(data_df.index)
     len_cols = len(data_df.columns)
@@ -683,20 +693,38 @@ def plot_node(
     plt.yticks(ticks=[y + .5 for y in yticks], labels=data_df.index[yticks])
     plt.xticks(ticks=[x + .5 for x in xticks], labels=data_df.columns[xticks], rotation=45, ha='right')
     plt.colorbar()
-    # sns.set(rc={'figure.figsize': (10, 10)})
-    # if data_df.max().max() > 50:
-    #     temp_data = data_df.fillna(.00001).replace(0, .1)
-    #     ax = sns.heatmap(temp_data, norm=LogNorm(clip=True))
-    # else:
-    #     temp_data = data_df.fillna(-1)
-    #     ax = sns.heatmap(temp_data)
-    #
     plt.title(f'{fancy_path}', fontsize=15)
     plt.xlabel('Update', fontsize=15)
     plt.ylabel('Reporting Date (Subject)', fontsize=15)
     save_plt_to_s3(plt, to_bucket, make_key(image_name, path), format='png')
-    plt.clf()
-    print('Cleared Image')
+
+    print('Clearing Heatmap')
+    plt.close()
+    print('Cleared Heatmap')
+
+
+    print("Creating Heatmap of Differences of Releases")
+    image_name = 'data_diff_heatmap.png'
+    plt.figure(figsize=(12, 12))
+    plt.pcolormesh(data_df.diff(axis=1), norm=LogNorm())
+    len_ind = len(data_df.index)
+    len_cols = len(data_df.columns)
+    ynum = max(len_ind // 10, 1)
+    xnum = max(len_cols // 5, 1)
+    yticks = [each for each in range(len_ind) if each % ynum == 0]
+    xticks = [each for each in range(len_cols) if each % xnum == 0]
+    plt.yticks(ticks=[y + .5 for y in yticks], labels=data_df.index[yticks])
+    plt.xticks(ticks=[x + .5 for x in xticks], labels=data_df.columns[xticks], rotation=45, ha='right')
+    plt.colorbar()
+    plt.title(f'{fancy_path} Release Differences', fontsize=15)
+    plt.xlabel('Update', fontsize=15)
+    plt.ylabel('Reporting Date (Subject)', fontsize=15)
+    save_plt_to_s3(plt, to_bucket, make_key(image_name, path), format='png')
+
+    print('Clearing Heatmap')
+    plt.close()
+    print('Cleared Heatmap')
+
 
     # create an image of the table
     print("Creating Summary Table")
@@ -717,7 +745,7 @@ def plot_node(
         cell_text.append([f'{shorten(x)}' for x in row])
 
     plt.figure(linewidth=2,
-               figsize=(10, 7)
+               figsize=(12, 7)
                )
     plt.tight_layout()
     # Add a table at the bottom of the axes
@@ -741,7 +769,10 @@ def plot_node(
     plt.suptitle(fancy_path, fontsize=20)
     plt.draw()
     save_plt_to_s3(plt, to_bucket, make_key(image_name, path), format='png')
-    plt.clf()
+
+    print('Clearing Image')
+    plt.close()
+    print('Cleared Image')
 
     return {
         'statusCode': 'temp_status',
